C  Documented in U.S. Geological Survey Open-File Report 94-468:
C  "A Data Input Program (MFI) for the U.S. Geological Survey Modular
C   Finite-Difference Ground-Water Flow Model" by Arlen W. Harbaugh
C
      PROGRAM   MFI
C  *********************************************************************
C     This program is used to enter data for a MODFLOW simulation
C  *********************************************************************
      INCLUDE 'mfi.gbl'
      COMMON /BASCOM/NSTP(MXPER),PERLEN(MXPER),TSMULT(MXPER)
C
      COMMON /FLWCOM/LAYCON(200)
      COMMON /FLWAVG/LAYAVG(200)
C
C     + + + LOCAL VARIABLES + + +
      CHARACTER*64  FNAME
      CHARACTER*8 APLOG
      DIMENSION IBUF(10)
      LOGICAL EX,EXMP
      CHARACTER*4 CUNIT(40)
      DATA CUNIT/'BCF ','WEL ','DRN ','RIV ','EVT ','TLK ','GHB ',
     1           'RCH ','SIP ','DE4 ','SOR ','OC  ','PCG ','GFD ',
     2           'CONC','HFB ','    ','STR ','IBS ','CHD ','    ',
     3           '    ','    ','    ','    ','    ','    ','    ',
     4           '    ','    ','    ','    ','    ','    ','    ',
     5           '    ','    ','    ','GAU ','    '/
C     + + + END SPECIFICATIONS + + +
C
C     set strings for use with RCS ident and what commands
      FNAME =
     &    '$Id: mfi.f,v 2.2 1997/01/22 15:29:22 rsregan Exp rsregan $'
      FNAME = '@(#)MFI - MODFLOW/MODPATH data input program'
      FNAME = '@(#)MFI - USGS OFR 94-468, Arlen W. Harbaugh'
      FNAME = '@(#)MFI - Contact: h2osoft@usgs.gov'
      FNAME = '@(#)MFI - Version: 2.3x 1996/12/06'
C
      MODINP=0
      MODOUT=0
      ISTRT=0
      IAPART=0
      ISUM=1
      NVAR=0
      NARRAY=0
      HEADNG(1)=' '
      HEADNG(2)=' '
      DO 4 I=1,200
      LAYCON(I)=0
      LAYAVG(I)=0
4     CONTINUE
C
C  All packages are off
      INBAS=0
      ILOUT=0
      IHEDUN=0
      IDDNUN=0
      IBUDUN=0
      DO 5 I=1,40
      IUNIT(I)=0
      IUNIT2(I)=0
5     CONTINUE
C
C  Set 1st 10 stress periods to undefined length and number of time steps.
C  This will force the user to define no more than 10 steps.  Previously,
C  all 200 periods were set to undefined, which meant all values had to
C  be defined in the AIDE spreadsheet if a user accidentally set NSTP=200.
C  This took a lot of keystrokes.  The new way sets default values of 1
C  for stress periods beyond 10 (in the block data routine), which means a
C  user can leave the spreadsheet after defining values for 10 stress periods.
      DO 6 I=1,10
      PERLEN(I)=-999.
      NSTP(I)=-999
6     CONTINUE
C
C  Define file units for use by MFI for log file and general use
      IOUT=98
      IUMISC=IOUT-1
C
C  Initialize files
      DO 7 I=1,MXFNAM
      IFNUSE(I)=0
      FILTYP(I)=' '
      FILNAM(I)=' '
7     CONTINUE
C
C  Initialize real and available file units
      CALL MFIUMK
C
C  The message file must be opened on unit 9
C  Initialize user environment and open message file
      MESSFL=9
      FNAME='mfi.wdm'
C  Add a directory name to the message file filename.
      CALL GETPNM(FNAME)
      APLOG='MFI'
      CALL ANINIZ(MESSFL,FNAME,APLOG)
      CALL ZSTCMA(2,0)
      CALL ZANSET('MFI 2.3')
C
C  Check for command line argument to be used as dataset.
      CALL NAMARG(DSNAME)
      IF(DSNAME.NE.' ') GO TO 11
C
C  No filename argument, so ask for dataset name.
10    CALL Q1INIT(MESSFL,300,1)
      CALL Q1EDIT(IRET)
      IF(IRET.EQ.-1) GO TO 10
      CALL QGETCT(1,8,8,DSNAME)
11    NDSNAM=LENSTR(8,DSNAME)
      IF(NDSNAM.LT.1) GO TO 10
      IF(IUCASE.NE.0) CALL USTRUC(DSNAME,NDSNAM)
C
C  Open log file and print some information about array sizes
      OPEN(UNIT=IOUT,FILE=DSNAME(1:NDSNAM)//'.log',ERR=10)
      WRITE(IOUT,*) ' MFI -- MODFLOW Data Editor'
      WRITE(IOUT,*)
      WRITE(IOUT,*) ' MODOUT:',MODOUT
      WRITE(IOUT,*) ' Length of X array:',LENX
      WRITE(IOUT,*) ' Maximum number of variables:',MXVAR
      WRITE(IOUT,*) ' Maximum number of arrays:',MXARR
      WRITE(IOUT,*) ' Maximum number of file names:',MXFNAM
      WRITE(IOUT,*) ' Maximum number of stress periods:',MXPER
      WRITE(IOUT,*) ' Maximum length of a list of stresses:',MXLIST*10
      WRITE(IOUT,*)
C
C  Check for an existing dataset
      INQUIRE(FILE=DSNAME(1:NDSNAM)//'.nam',EXIST=EX)
C
      IF(EX) THEN
C  There is an old dataset, so process it
C  Close AIDE while reading model data in case there are file unit
C  conflicts
         INQUIRE(FILE=DSNAME(1:NDSNAM)//'.mpn',EXIST=EXMP)
         INMP=0
         IF(EXMP) INMP=1
         OPEN(UNIT=IUMISC,FILE=DSNAME(1:NDSNAM)//'.nam',STATUS='OLD',
     1           ERR=10)
         CALL ANCLOS(MESSFL)
         WRITE(*,*) ' Reading existing data.  Please wait . . .'
         NMISS=0
         CALL MFREAD(IUMISC,CUNIT,IWARN,INMP)
         IF(INMP.GT.0) THEN
            OPEN(UNIT=IUMISC,FILE=DSNAME(1:NDSNAM)//'.mpn',STATUS='OLD')
            CALL MPNAM(IUMISC)
            CALL MPRP(IWARN)
         END IF
C  Reinitialize MODFLOW's real units now that all data are read.  Even
C  if MODPATH data have not been read, MODFLOW's units are
C  reinitialized because IUREAL for INBAS and ILOUT may not be set to the
C  values that BASSV will set (5 and 6).
         CALL MFIUMK
         IF(ILOUT.EQ.0) THEN
            CALL FINDUN(2,IU,'LST')
            ILOUT=IU
         END IF
         CALL ANINIZ (MESSFL,FNAME,APLOG )
         CALL ZSTCMA(2,0)
         CALL ZANSET(DSNAME(1:NDSNAM)//'  MFI 2.3')
         IF(IWARN.GT.0) CALL DSPTXT(MESSFL,300,17,CTEXT,NMISS,78)
      ELSE
C  New dataset -- check if that's what the user expects
         IOPT=1
         CALL QRESP(MESSFL,300,2,IOPT)
         IF(IOPT.EQ.2) THEN
            CALL ANCLOS(MESSFL)
            CLOSE(UNIT=IOUT,STATUS='DELETE')
            STOP
         END IF
         INQUIRE(FILE=DSNAME(1:NDSNAM)//'.bas',EXIST=EX)
         IF(EX) GO TO 10
         INQUIRE(FILE=DSNAME(1:NDSNAM)//'.bcf',EXIST=EX)
         IF(EX) GO TO 10
         INQUIRE(FILE=DSNAME(1:NDSNAM)//'.nam',EXIST=EX)
         IF(EX) GO TO 10
C  Now get size of grid and the type of model (MODFLOW-88 or MODFLOW-96).
         CALL ZANSET(DSNAME(1:NDSNAM)//'  MFI 2.3')
95       CALL Q1INIT(MESSFL,300,3)
         IMTYP=MODOUT+1
         CALL QSETOP(1,1,1,1,IMTYP)
         CALL Q1EDIT(IRET)
         IF(IRET.EQ.-1) GO TO 95
         CALL QGETOP(1,IMTYP)
         MODOUT=IMTYP-1
         CALL QGETI(3,IBUF)
         NLAY=IBUF(1)
         NROW=IBUF(2)
         NCOL=IBUF(3)
         IF(NLAY.GT.80 .AND. MODOUT.EQ.0) THEN
            CALL PRNTXT(MESSFL,300,27)
            GO TO 95
         END IF
C  If only 1 row and using new model, ask about cross section option
         IXSEC=0
         IF(NROW.EQ.1 .AND. MODOUT.NE.0) THEN
            IX=1
            CALL QRESP(MESSFL,300,24,IX)
            IF(IX.EQ.1) IXSEC=1
         END IF
         CALL IVLSAV('IXSEC',0,0,IXSEC)
C  Activate BAS Package
         CALL FINDUN(1,IU,'BAS')
         INBAS=IU
         CALL FINDUN(2,IU,'LST')
         ILOUT=IU
         NPER=1
         ISS=1
         NSTP(1)=1
         PERLEN(1)=1.
      END IF
C
C  Choose the package (or other option) to work on
      IOPT=1
100   CALL QRESP ( MESSFL, 300, 4,IOPT )
      IF(IOPT.EQ.1) THEN
         CALL BASED
      ELSE IF(IOPT.EQ.2) THEN
         CALL BCFED
      ELSE IF(IOPT.EQ.3) THEN
         CALL STRESS
      ELSE IF(IOPT.EQ.4) THEN
         CALL SOLVED
      ELSE IF(IOPT.EQ.5) THEN
         CALL OCED
      ELSE IF(IOPT.EQ.6) THEN
         CALL MPED
      ELSE IF(IOPT.EQ.7) THEN
         CALL MOCED
      ELSE IF(IOPT.EQ.8) THEN
         CALL ACTIVE
         IOPT=IOPT-1
      ELSE IF(IOPT.EQ.9) THEN
         CALL DEACT
         IOPT=7
      ELSE IF(IOPT.EQ.10) THEN
         CALL FILDSP
         IOPT=7
      ELSE IF(IOPT.EQ.11) THEN
         CALL RENAME
         IOPT=7
      ELSE IF(IOPT.EQ.13) THEN
C  Abort
         IRESP=2
         CALL QRESP(MESSFL,300,35,IRESP)
         IF(IRESP.EQ.1) THEN
            CALL ANCLOS(MESSFL)
            STOP
         END IF
         IOPT=7
      ELSE
C  Exit.
         CALL PMXCNW(MESSFL,300,25,10,1,1,N)
         CALL SAVALL(2,IERR)
         IF(IERR.NE.0) THEN
C  Incomplete data -- ask user about continuing to edit.
            IRESP=2
            CALL QRESP(MESSFL,300,18,IRESP)
            IF(IRESP.NE.1) THEN
               IOPT=8
               GO TO 100
            END IF
         END IF
C  Done saving data -- write some information to the log file for
C  diagnostic purposes and quit.
         DO 145 I=1,NVAR
         WRITE(IOUT,*) VARNAM(I),VARVAL(I),(IVARDA(J,I),J=1,3)
145      CONTINUE
         DO 146 I=1,MXFNAM
         IF(FILTYP(I).NE.' ') WRITE(IOUT,*)
     1        I,IUREAL(I),' ',FILTYP(I),FILNAM(I)(1:40)
146      CONTINUE
         WRITE(IOUT,*) 'ISUM=',ISUM
         CALL ANCLOS(MESSFL)
         STOP
      END IF
C
C  End of main menu IF loop -- the selected option has been processed.
C  Redisplay main menu.
      IOPT=IOPT+1
      GO TO 100
      END
      SUBROUTINE ACTIVE
C     ******************************************************************
C     Display active packages and whether or not data are complete
C     ******************************************************************
      INCLUDE 'mfi.gbl'
      CHARACTER*20 CVAL(20)
C
      NPACK=0
C
      IF(INBAS.NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='BAS'
         CALL BASSV(IUNDEF,0,NPER)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(1).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='BCF'
         CALL BCFSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(4).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='RIV'
         CALL RIVSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(18).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='STR'
         CALL STRSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(7).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='GHB'
         CALL GHBSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(8).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='RCH'
         CALL RCHSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(2).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='WEL'
         CALL WELSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(3).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='DRN'
         CALL DRNSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(5).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='EVT'
         CALL EVTSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(13).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='PCG'
         CALL SOLVSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(9).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='SIP'
         CALL SOLVSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(10).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='DE4'
         CALL SOLVSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(11).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='SOR'
         CALL SOLVSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(12).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='OC'
         CALL OCSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(15).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='MOC'
         CALL MOCSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      IF(IUNIT(40).NE.0) THEN
         NPACK=NPACK+1
         CVAL(NPACK)='MODPATH'
         CALL MPSV(IUNDEF,0)
         IF(IUNDEF.NE.0) THEN
            CVAL(NPACK)(11:20)='INCOMPLETE'
         ELSE
            CVAL(NPACK)(11:20)='COMPLETE'
         END IF
      END IF
C
      CALL DSPTXT(MESSFL,300,10,CVAL,NPACK,20)
      RETURN
      END
      SUBROUTINE SAVALL(IWRFLG,IERR)
C     ******************************************************************
C     SAVE ALL DATA
C     IWRFLG=2 for save data in package files
C     IWRFLG=1 for save in "MFI" backup files
C     IWRFLG=0 for check for undefined data without saving the data --
C          simply set IUNDEF not 0 if data are undefined.
C     IWRFLG=-1 for check for undefined data without saving the data --
C          display undefined data using DSPTXT routine.
C     ******************************************************************
C
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
      INCLUDE 'mfi.gbl'
C     ------------------------------------------------------------------
C
      ISTRT=0
      IAPART=0
      IERR=0
      CALL BCFSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
      CALL WELSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
      CALL DRNSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
      CALL RIVSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
      CALL STRSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
      CALL EVTSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
      CALL GHBSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
      CALL RCHSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
      CALL SOLVSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
      CALL OCSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
      CALL MOCSV(IUNDEF,IWRFLG)
      IF(IUNDEF.GT.0) IERR=1
C  Call BAS last so that IAPART and ISTRT can get set by other packages
      CALL BASSV(IUNDEF,IWRFLG,NPER)
      IF(IUNDEF.GT.0) IERR=1
      CALL NAMESV(IWRFLG)
C
      IF(IUNIT(40).GT.0) THEN
         CALL MPIUMK
         CALL MPSV(IUNDEF,IWRFLG)
         IF(IUNDEF.GT.0) IERR=1
         CALL MPNMSV(IWRFLG)
         CALL MFIUMK
      END IF
C
      RETURN
      END
      SUBROUTINE NAMESV(IWRFLG)
C     ******************************************************************
C     SAVE NAME FILE
C     ******************************************************************
C
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
      INCLUDE 'mfi.gbl'
C  Common block for MOC
      COMMON /MOCCOM/IUMOCL,IUMOC,IUCRC,IUCOBS,NSCOL,NSROW,NSLAY,
     1     ISLAY1,ISLAY2,ISROW1,ISROW2,ISCOL1,ISCOL2,
     2     NODISP,NPTPND,ICINFL,
     3     PNEWL(51),PNEWR(51),PNEWC(51),IZONE(MXCZON),ZONCON(MXCZON),
     4     ICOB(3,MXCOB),ICOBFL(MXCOB)
C     ------------------------------------------------------------------
      IF(IWRFLG.LT.1) RETURN
      IF(IWRFLG.EQ.1) OPEN(FILE='MFI.NAM',UNIT=IUMISC)
      IF(IWRFLG.GT.1) OPEN(FILE=DSNAME(1:NDSNAM)//'.nam',UNIT=IUMISC)
C  Write the listing file followed by the Basic Package file
      IF(ILOUT.NE.0) THEN
         J=LENSTR(80,FILNAM(ILOUT))
         WRITE(IUMISC,25) FILTYP(ILOUT),IUREAL(ILOUT),
     1              FILNAM(ILOUT)(1:J)
      END IF
      IF(INBAS.NE.0) THEN
         J=LENSTR(80,FILNAM(INBAS))
         WRITE(IUMISC,25) FILTYP(INBAS),IUREAL(INBAS),FILNAM(INBAS)(1:J)
      END IF
C
C  Write all other files
      DO 10 I=1,MXFNAM
      IF(IFNUSE(I).NE.0 .AND. IFNUSE(I).NE.IUNIT(40) .AND.
     1      FILTYP(I)(1:10).NE.'OPEN/CLOSE' .AND.
     1      I.NE.INBAS .AND. I.NE.ILOUT .AND. IFNUSE(I).NE.IUMOC) THEN
         J=LENSTR(80,FILNAM(I))
         IF(IUREAL(I).EQ.0) CALL REALUN(I)
         WRITE(IUMISC,25) FILTYP(I),IUREAL(I),FILNAM(I)(1:J)
      END IF
10    CONTINUE
      CLOSE(UNIT=IUMISC)
C Write computer-dependent file for opening files if using original MODFLOW.
      IF(IWRFLG.GT.1 .AND. MODOUT.EQ.0) CALL ORGOPN
      RETURN
25    FORMAT(A,I5,1X,A,A)
      END
      SUBROUTINE MFREAD(INUNIT,CUNIT,IWARN,INMP)
C     ******************************************************************
C     Read a MODFLOW data set.  This is based on the AL and RP modules
C        from MODFLOW.
C           BY ARLEN W. HARBAUGH
      INCLUDE 'mfi.gbl'
      COMMON /BASCOM/NSTP(MXPER),PERLEN(MXPER),TSMULT(MXPER)
      DIMENSION IOFLG(200,4)
      CHARACTER*4 CUNIT(40)
      DIMENSION NTSOUT(6),INONE(6),IEND(6),IALPER(6),IALSTP(6)
      CHARACTER*6 CCPER
C     ------------------------------------------------------------------
C  Clear input error warning flag
      IWARN=0
C  Clear counters and flags for output control data
      DO 10 I=1,6
C  Number of time steps for which output control is specified for
C  hdpr,ddpr,hdsv,ddsv,bdpr,bdsv
      NTSOUT(I)=0
C  Flags for no output for any time step
      INONE(I)=1
C  Flags for output only at end of simulation
      IEND(I)=1
C  Flags for output at end of each stress period
      IALPER(I)=1
C  Flags for output at end of each time step
      IALSTP(I)=1
10    CONTINUE
C  flag that checks if all CBC flags are the same
      IBDSAM=-2
C
C3------DEFINE PROBLEM__ROWS,COLUMNS,LAYERS,STRESS PERIODS,PACKAGES
      CALL SBASO(INUNIT,CUNIT)
      IF(INBAS.EQ.0) THEN
         WRITE(IOUT,*) ' No BAS Package file was defined'
         CALL RDABRT
      END IF
      IF(INBAS.GT.0) CALL BASDF
C
C4------ALLOCATE SPACE IN "X" ARRAY.
      IF(INBAS.GT.0) CALL BASAL()
      IF(IUNIT(12).GT.0) CALL OCRP(IPEROC,ITSOC)
      IF(IUNIT(1).GT.0) CALL BCFAL(IBDSAM)
      IF(IUNIT(2).GT.0) CALL WELAL(IBDSAM,INMP)
      IF(IUNIT(3).GT.0) CALL DRNAL(IBDSAM,INMP)
      IF(IUNIT(4).GT.0) CALL RIVAL(IBDSAM,INMP)
      IF(IUNIT(18).GT.0) CALL STRAL(IBDSAM,INMP,NSS,NTRIB,NDIV,ICALC)
      IF(IUNIT(5).GT.0) CALL EVTAL(IBDSAM)
      IF(IUNIT(7).GT.0) CALL GHBAL(IBDSAM,INMP)
      IF(IUNIT(8).GT.0) CALL RCHAL(IBDSAM)
      IF(IUNIT(9).GT.0) CALL SIPAL()
      IF(IUNIT(10).GT.0) CALL DE4AL()
      IF(IUNIT(11).GT.0) CALL SORAL()
      IF(IUNIT(13).GT.0) CALL PCGAL()
C
C6------READ AND PREPARE INFORMATION FOR ENTIRE SIMULATION.
      IF(INBAS.GT.0) CALL BASRP()
      IF(IUNIT(1).GT.0) CALL BCFRP()
      IF(IUNIT(9).GT.0) CALL SIPRP()
      IF(IUNIT(10).GT.0) CALL DE4RP()
      IF(IUNIT(11).GT.0) CALL SORRP()
      IF(IUNIT(13).GT.0) CALL PCGRP()
      IF(IUNIT(15).GT.0) CALL MOCRD()
C
C7------SIMULATE EACH STRESS PERIOD.
      DO 300 KPER=1,NPER
      KKPER=KPER
C
C7A-----READ STRESS PERIOD TIMING INFORMATION.
      IF(INBAS.GT.0) CALL BASST(KKPER)
C
C7B-----READ AND PREPARE INFORMATION FOR STRESS PERIOD.
      IF(IUNIT(2).GT.0) CALL WELRP(KKPER,IWARN)
      IF(IUNIT(3).GT.0) CALL DRNRP(KKPER,IWARN)
      IF(IUNIT(4).GT.0) CALL RIVRP(KKPER,IWARN)
      IF(IUNIT(18).GT.0) CALL STRRP(KKPER,IWARN,NSS,NTRIB,NDIV,ICALC)
      IF(IUNIT(5).GT.0) CALL EVTRP(KKPER)
      IF(IUNIT(7).GT.0) CALL GHBRP(KKPER,IWARN)
      IF(IUNIT(8).GT.0) CALL RCHRP(KKPER)
      IF(IUNIT(12).GT.0) THEN
         DO 299 KSTP=1,NSTP(KPER)
         KKSTP=KSTP
         CALL BASOC(KKSTP,KKPER,IPEROC,ITSOC,IOFLG,
     1     NTSOUT,INONE,IEND,IALPER,IALSTP)
  299    CONTINUE
      END IF
  300 CONTINUE
C
C8------CLOSE ALL FILES
      CALL SBASC()
C
C  If no BCF data, set ISS based on NPER
      IF(IUNIT(1).LE.0) THEN
         ISS=1
         IF(NPER.GT.1) ISS=0
      END IF
C
C  Set output control frequency flags and IBUDUN
      IF(IUNIT(12).GT.0) CALL OCFREQ(INONE,IEND,IALPER,IALSTP,IBDSAM)
C
C  If steady state, force a single time step for each stress period.
      IF(ISS.NE.0) THEN
         DO 400 I=1,NPER
         IF(NSTP(I).NE.1) THEN
            WRITE(IOUT,*)
     1 ' WARNING -- forcing 1 time step in steady-state stress period',I
            IWARN=IWARN+1
            IF(NMISS.LT.45) THEN
               WRITE(CCPER,'(I6)') I
               NMISS=NMISS+1
               CTEXT(NMISS)=
     1   ' WARNING -- forcing 1 time step in steady-state stress period'
     2               //CCPER
            END IF
            NSTP(I)=1
            TSMULT(1)=1.
         END IF
400      CONTINUE
      END IF
C
C  Turn off extra solvers
      IF(IUNIT(13).NE.0) THEN
         IF(IUNIT(9).NE.0) THEN
            IFNUSE(IUNIT(9))=0
            IUNIT(9)=0
         END IF
         IF(IUNIT(10).NE.0) THEN
            IFNUSE(IUNIT(10))=0
            IUNIT(10)=0
         END IF
         IF(IUNIT(11).NE.0) THEN
            IFNUSE(IUNIT(11))=0
            IUNIT(11)=0
         END IF
      ELSE IF(IUNIT(9).NE.0) THEN
         IF(IUNIT(10).NE.0) THEN
            IFNUSE(IUNIT(10))=0
            IUNIT(10)=0
         END IF
         IF(IUNIT(11).NE.0) THEN
            IFNUSE(IUNIT(11))=0
            IUNIT(11)=0
         END IF
      ELSE IF(IUNIT(10).NE.0) THEN
         IF(IUNIT(11).NE.0) THEN
            IFNUSE(IUNIT(11))=0
            IUNIT(11)=0
         END IF
      END IF
C
      RETURN
      END
      SUBROUTINE RDABRT
C     ******************************************************************
C     PRINT A MESSAGE AND STOP AFTER THERE IS AN INPUT ERROR
C     ******************************************************************
      INCLUDE 'mfi.gbl'
C
      WRITE(*,*) ' Error while reading input data'
      WRITE(*,*) ' Look in log file to find the cause of the error'
      WRITE(*,*) ' Preprocessor cannot continue'
      STOP
      END
      SUBROUTINE DEACT
C     ******************************************************************
C     DEACTIVATE PACKAGES
C     ******************************************************************
      INCLUDE 'mfi.gbl'
      COMMON /MPCOM/IGUAUN,IGUAM,GUAMIN(15),GUAMAX(15),NCON(200)
      COMMON /MOCCOM/IUMOCL,IUMOC,IUCRC,IUCOBS,NSCOL,NSROW,NSLAY,
     1     ISLAY1,ISLAY2,ISROW1,ISROW2,ISCOL1,ISCOL2,
     2     NODISP,NPTPND,ICINFL,
     3     PNEWL(51),PNEWR(51),PNEWC(51),IZONE(MXCZON),ZONCON(MXCZON),
     4     ICOB(3,MXCOB),ICOBFL(MXCOB)
      DIMENSION ICVAL(40)
      CHARACTER*3 CFTYP(40)
      CHARACTER*78 CBUF
      LOGICAL EXMP
C
C  Find which packages are active
      N=0
      DO 10 I=1,40
      IF(IUNIT(I).EQ.0) GO TO 10
      N=N+1
      CFTYP(N)=FILTYP(IUNIT(I))
      IF(I.EQ.15) CFTYP(N)='MOC'
      ICVAL(N)=1
10    CONTINUE
C
      IF(N.GT.0) THEN
C  Initialize screen
12       CALL Q2INIT(MESSFL,300,21)
C  Set initial values
         CALL Q2SCTF(1,3,N,CFTYP)
         CALL Q2SCOB(1,2,N,ICVAL)
C  Activate screen
         CALL Q2EDIT(N,IRET)
         IF(IRET.EQ.-1) GO TO 12
C  Get responses
         CALL Q2GCOB(1,2,N,ICVAL)
C  Check each option to see if it should be deactivated
         N=0
         DO 50 I=1,40
         IU=IUNIT(I)
         IF(IU.EQ.0) GO TO 50
         N=N+1
         IF(ICVAL(N).EQ.2) THEN
C  If deactivated is selected, confirm it to be sure
            CBUF=' '
            WRITE(CBUF,'(3A)')
     1        'Are you sure you want to deactivate ',
     2         CFTYP(N),'?'
            CALL ZBLDWR(78,CBUF,1,-1,IFLG)
            CALL ZMNSST
            IANS=2
            CALL QRESP(MESSFL,300,22,IANS)
            IF(IANS.EQ.2) GO TO 50
C  User confirms, so deactivate -- set IUNIT=0
            IUNIT(I)=0
C  Set in-use flag to 0 for any files that were used by this option.
            DO 40 J=1,MXFNAM
            IF(IFNUSE(J).EQ.IU) IFNUSE(J)=0
40          CONTINUE
C  Set INUIT2 to 0 as well as the in-use flag for a cbc budget file
C  used only by this package.
            IF(IUNIT2(I).GT.0) THEN
               NBD=0
               DO 45 L=1,40
               IF(IUNIT2(L).EQ.IUNIT2(I)) NBD=NBD+1
45             CONTINUE
               IF(NBD.EQ.1) IFNUSE(IUNIT2(I))=0
            END IF
            IUNIT2(I)=0
C  For OC, turn off all budget saving.
            IF(I.EQ.12) THEN
               DO 46 L=1,40
               IUNIT2(L)=0
46             CONTINUE
               IBUDUN=0
               IHEDUN=0
               IDDNUN=0
            END IF
C  For MODPATH, delete an existing MODPATH name file -- otherwise, this
C  name file would reactivate MODPATH the next time mfi is used to edit
C  this data set.  Also, reset IGUAUN
            IF(I.EQ.40) THEN
               INQUIRE(FILE=DSNAME(1:NDSNAM)//'.mpn',EXIST=EXMP)
               IF(EXMP) THEN
                  OPEN(UNIT=IUMISC,FILE=DSNAME(1:NDSNAM)//'.mpn',
     1               STATUS='OLD')
                  CLOSE(UNIT=IUMISC,STATUS='DELETE')
               END IF
               IGUAUN=0
               IGUAM=1
            END IF
C
C  For MOC, clear ICOB and set IFNUSE=0 for all IUMOC files.
            IF(I.EQ.15) THEN
               DO 48 J=1,MXCOB
               ICOBFL(J)=0
               DO 48 JJ=1,3
               ICOB(JJ,J)=0
48             CONTINUE
               DO 49 J=1,MXFNAM
               IF(IFNUSE(J).EQ.IUMOC) IFNUSE(J)=0
49             CONTINUE
               IUMOC=0 
               IUMOCL=0
               IUCRC=0
               IUCOBS=0
            END IF
C
         END IF
50       CONTINUE
C
C  Remove any files that have IFNUSE=0
         CALL FNMRMV
      END IF
C
      RETURN
      END
      SUBROUTINE FILDSP
C     ******************************************************************
C     Display files being used
C     ******************************************************************
      INCLUDE 'mfi.gbl'
      CHARACTER*78 CVAL(45)
      CHARACTER*8 FILUSE
      COMMON /MOCCOM/IUMOCL,IUMOC,IUCRC,IUCOBS,NSCOL,NSROW,NSLAY,
     1     ISLAY1,ISLAY2,ISROW1,ISROW2,ISCOL1,ISCOL2,
     2     NODISP,NPTPND,ICINFL,
     3     PNEWL(51),PNEWR(51),PNEWC(51),IZONE(MXCZON),ZONCON(MXCZON),
     4     ICOB(3,MXCOB),ICOBFL(MXCOB)
C
      NFILE=0
C
C  Display the list file first
      IF(ILOUT.GT.0) THEN
         NFILE=NFILE+1
         FILUSE='LIST'
         WRITE(CVAL(NFILE),33) FILUSE,FILTYP(ILOUT),FILNAM(ILOUT)
      END IF
C
C  Display all files connected to INBAS
      IF(INBAS.GT.0) THEN
         FILUSE=FILTYP(INBAS)(1:8)
         DO 40 I=1,MXFNAM
         IF(IFNUSE(I).NE.INBAS) GO TO 40
         NFILE=NFILE+1
         WRITE(CVAL(NFILE),33) FILUSE,FILTYP(I),FILNAM(I)
         IF(NFILE.EQ.45) THEN
            CALL DSPTXT(MESSFL,300,23,CVAL,NFILE,78)
            NFILE=0
         END IF
40       CONTINUE
      END IF
C
C  Display all files connected to IUNIT
      DO 100 M=1,40
      IF(IUNIT(M).GT.0) THEN
         FILUSE=FILTYP(IUNIT(M))(1:8)
         DO 50 I=1,MXFNAM
         IF(IFNUSE(I).NE.IUNIT(M)) GO TO 50
         NFILE=NFILE+1
         WRITE(CVAL(NFILE),33) FILUSE,FILTYP(I),FILNAM(I)
33       FORMAT(A,2X,A,2X,A48)
         IF(NFILE.EQ.45) THEN
            CALL DSPTXT(MESSFL,300,23,CVAL,NFILE,78)
            NFILE=0
         END IF
50       CONTINUE
      END IF
100   CONTINUE
C
C  Display all file names associated with IUMOC
      IF(IUMOC.GT.0) THEN
         DO 200 I=1,MXFNAM
         IF(IFNUSE(I).NE.IUMOC) GO TO 200
         NFILE=NFILE+1
         FILUSE='MOC'
         WRITE(CVAL(NFILE),33) FILUSE,FILTYP(I),FILNAM(I)
         IF(NFILE.EQ.45) THEN
            CALL DSPTXT(MESSFL,300,23,CVAL,NFILE,78)
            NFILE=0
         END IF
200      CONTINUE
      END IF
C
C  Display all reserved files
      DO 220 I=1,MXFNAM
      IF(IFNUSE(I).GE.0) GO TO 220
      NFILE=NFILE+1
      FILUSE='RESERVED'
      WRITE(CVAL(NFILE),33) FILUSE,FILTYP(I),FILNAM(I)
      IF(NFILE.EQ.45) THEN
         CALL DSPTXT(MESSFL,300,23,CVAL,NFILE,78)
         NFILE=0
      END IF
220   CONTINUE
C
C  Finish showing a partial screen
      IF(NFILE.GT.0) CALL DSPTXT(MESSFL,300,23,CVAL,NFILE,78)
      RETURN
      END
      SUBROUTINE STRESS
C     ******************************************************************
C     Menu for editing stresses
C     ******************************************************************
      INCLUDE 'mfi.gbl'
C
      IOPT=1
10    CALL QRESP(MESSFL,307,1,IOPT)
      IF(IOPT.EQ.1) THEN
         CALL RIVED
      ELSE IF(IOPT.EQ.2) THEN
         CALL RCHED
      ELSE IF(IOPT.EQ.3) THEN
         CALL WELED
      ELSE IF(IOPT.EQ.4) THEN
         CALL DRNED
      ELSE IF(IOPT.EQ.5) THEN
         CALL EVTED
      ELSE IF(IOPT.EQ.6) THEN
         CALL GHBED
      ELSE IF(IOPT.EQ.7) THEN
         CALL STRED
      ELSE IF(IOPT.EQ.8) THEN
         NMISS=0
         IF(IUNIT(2).GT.0) CALL WELSV(IUNDEF,-1)
         IF(IUNIT(3).GT.0) CALL DRNSV(IUNDEF,-1)
         IF(IUNIT(4).GT.0) CALL RIVSV(IUNDEF,-1)
         IF(IUNIT(7).GT.0) CALL GHBSV(IUNDEF,-1)
         IF(IUNIT(8).GT.0) CALL RCHSV(IUNDEF,-1)
         IF(IUNIT(5).GT.0) CALL EVTSV(IUNDEF,-1)
         IF(IUNIT(18).GT.0) CALL STRSV(IUNDEF,-1)
         IF(NMISS.GT.0) THEN
            CALL DSPTXT(MESSFL,307,2,CTEXT,NMISS,50)
         ELSE
            CALL PRNTXT(MESSFL,307,3)
         END IF
C
      ELSE
         RETURN
      END IF
      IOPT=IOPT+1
      GO TO 10
      END
      SUBROUTINE RENAME
C     ******************************************************************
C     Rename the dataset
C     ******************************************************************
      INCLUDE 'mfi.gbl'
      COMMON /MPCOM/IGUAUN,IGUAM,GUAMIN(15),GUAMAX(15),NCON(200)
      CHARACTER*8 NEWNAM
      LOGICAL EX
      CHARACTER*3 CEXTN
C
C  Prompt for new name
10    CALL Q1INIT(MESSFL,300,33)
      CALL Q1EDIT(IRET)
      IF(IRET.EQ.-1) GO TO 10
      CALL QGETCT(1,8,8,NEWNAM)
      NNEW=LENSTR(8,NEWNAM)
      IF(NNEW.LT.1) GO TO 300
      IF(IUCASE.NE.0) CALL USTRUC(NEWNAM,NNEW)
C
C  First check if each new file name is unique
C
C  Name file
      INQUIRE(FILE=NEWNAM(1:NNEW)//'.nam',EXIST=EX,ERR=100)
      IF(EX) GO TO 100
C
C  Basic Package
      INQUIRE(FILE=NEWNAM(1:NNEW)//'.bas',EXIST=EX,ERR=100)
      IF(EX) GO TO 100
C
C  ILOUT
      INQUIRE(FILE=NEWNAM(1:NNEW)//'.lst',EXIST=EX,ERR=100)
      IF(EX) GO TO 100
C
C  Other Packages -- all files included in IUNIT
      DO 20 I=1,40
      IF(IUNIT(I).LE.0) GO TO 20
      CEXTN=FILTYP(IUNIT(I))(1:3)
      IF(IUCASE.EQ.0) CALL USTRLC(CEXTN,3)
      INQUIRE(FILE=NEWNAM(1:NNEW)//'.'//CEXTN,EXIST=EX,ERR=100)
      IF(EX) GO TO 100
20    CONTINUE
C
C  Head, drawdown, budget, and GUA files
      INQUIRE(FILE=NEWNAM(1:NNEW)//'.hed',EXIST=EX,ERR=100)
      IF(EX) GO TO 100
      INQUIRE(FILE=NEWNAM(1:NNEW)//'.ddn',EXIST=EX,ERR=100)
      IF(EX) GO TO 100
      INQUIRE(FILE=NEWNAM(1:NNEW)//'.bud',EXIST=EX,ERR=100)
      IF(EX) GO TO 100
      INQUIRE(FILE=NEWNAM(1:NNEW)//'.gua',EXIST=EX,ERR=100)
      IF(EX) GO TO 100
C
C  Make sure that none of the existing files start with the new name
      DO 30 I=1,MXFNAM
      IF(NEWNAM(1:NNEW)//'.'.EQ.FILNAM(I)(1:NNEW)//'.') GO TO 200
30    CONTINUE
C
C  Now actually try to open the name file, which should detect if
C  there is anything invalid about the filename.
      OPEN(UNIT=IUMISC,FILE=NEWNAM(1:NNEW)//'.nam',ERR=100)
      CLOSE(UNIT=IUMISC,STATUS='DELETE')
C
C  All file names are unique -- change them in the list of file names
C
C  Basic Package
      IF(INBAS.GT.0) THEN
         IF(IUCASE.NE.0) FILNAM(INBAS)=NEWNAM(1:NNEW)//'.BAS'
         IF(IUCASE.EQ.0) FILNAM(INBAS)=NEWNAM(1:NNEW)//'.bas'
      END IF
C
C  ILOUT
      IF(ILOUT.GT.0) THEN
         IF(IUCASE.NE.0) FILNAM(ILOUT)=NEWNAM(1:NNEW)//'.LST'
         IF(IUCASE.EQ.0) FILNAM(ILOUT)=NEWNAM(1:NNEW)//'.lst'
      END IF
C
C  Other Packages -- all files included in IUNIT
      DO 40 I=1,40
      IF(IUNIT(I).LE.0) GO TO 40
      CEXTN=FILTYP(IUNIT(I))(1:3)
C  Special case for MOC name file
      IF(CEXTN.EQ.'CON') CEXTN='CNC'
      IF(IUCASE.EQ.0) CALL USTRLC(CEXTN,3)
      FILNAM(IUNIT(I))=NEWNAM(1:NNEW)//'.'//CEXTN
      IF(IUNIT2(I).LE.0) GO TO 40
      IF(IUCASE.NE.0) THEN
         IF(FILNAM(IUNIT2(I)).EQ.DSNAME(1:NDSNAM)//'.BUD')
     1       FILNAM(IUNIT2(I))=NEWNAM(1:NNEW)//'.BUD'
      ELSE
         IF(FILNAM(IUNIT2(I)).EQ.DSNAME(1:NDSNAM)//'.bud')
     1       FILNAM(IUNIT2(I))=NEWNAM(1:NNEW)//'.bud'
      END IF
40    CONTINUE
C
C  Head, drawdown, budget, and GUA files
      IF(IUCASE.NE.0) THEN
         IF(IHEDUN.GT.0) FILNAM(IHEDUN)=NEWNAM(1:NNEW)//'.HED'
         IF(IDDNUN.GT.0) FILNAM(IDDNUN)=NEWNAM(1:NNEW)//'.DDN'
         IF(IBUDUN.GT.0) FILNAM(IBUDUN)=NEWNAM(1:NNEW)//'.BUD'
         IF(IGUAUN.GT.0) FILNAM(IGUAUN)=NEWNAM(1:NNEW)//'.GUA'
      ELSE
         IF(IHEDUN.GT.0) FILNAM(IHEDUN)=NEWNAM(1:NNEW)//'.hed'
         IF(IDDNUN.GT.0) FILNAM(IDDNUN)=NEWNAM(1:NNEW)//'.ddn'
         IF(IBUDUN.GT.0) FILNAM(IBUDUN)=NEWNAM(1:NNEW)//'.bud'
         IF(IGUAUN.GT.0) FILNAM(IGUAUN)=NEWNAM(1:NNEW)//'.gua'
      END IF
C
C  MOC file types
      DO 50 I=1,MXFNAM
      IF(FILTYP(I).EQ.'CLST') THEN
         IF(IUCASE.NE.0) FILNAM(I)=NEWNAM(1:NNEW)//'.LSM'
         IF(IUCASE.EQ.0) FILNAM(I)=NEWNAM(1:NNEW)//'.lsm'
      END IF
      IF(FILTYP(I).EQ.'MOC') THEN
         IF(IUCASE.NE.0) FILNAM(I)=NEWNAM(1:NNEW)//'.MOC'
         IF(IUCASE.EQ.0) FILNAM(I)=NEWNAM(1:NNEW)//'.moc'
      END IF
      IF(FILTYP(I).EQ.'OBS') THEN
         IF(IUCASE.NE.0) FILNAM(I)=NEWNAM(1:NNEW)//'.OBS'
         IF(IUCASE.EQ.0) FILNAM(I)=NEWNAM(1:NNEW)//'.obs'
      END IF
      IF(FILTYP(I).EQ.'CRCH') THEN
         IF(IUCASE.NE.0) FILNAM(I)=NEWNAM(1:NNEW)//'.CRC'
         IF(IUCASE.EQ.0) FILNAM(I)=NEWNAM(1:NNEW)//'.crc'
      END IF
50    CONTINUE
C
C  Save the new name and save the dataset
      DSNAME=NEWNAM
      NDSNAM=NNEW
      CALL PMXCNW(MESSFL,300,25,10,1,1,N)
      CALL SAVALL(2,IERR)
C  Add new name to screen title
      CALL ZANSET(DSNAME(1:NDSNAM)//'  MFI 2.3')
      RETURN
C
C  ERRORS -- for any error, give a message and return
100   CALL PRNTXT(MESSFL,300,28)
      RETURN
200   CALL PRNTXT(MESSFL,300,29)
      RETURN
300   CALL PRNTXT(MESSFL,300,34)
      RETURN
C
      END
      BLOCK DATA
      INCLUDE 'mfi.gbl'
C  Numeric common block for MODPATH
      COMMON /MPCOM/IGUAUN,IGUAM,GUAMIN(15),GUAMAX(15),NCON(200)
C  Character common block for MODPATH
      PARAMETER (NSPEC=12)
      COMMON /MPCCOM/MPNAME,MPTYPE,CLEGND(15),CLTITL
      CHARACTER*60 MPNAME(NSPEC)
      CHARACTER*16 MPTYPE(NSPEC)
      CHARACTER*30 CLEGND
      CHARACTER*50 CLTITL
      PARAMETER (IDIM=MXSCRN*17)
C  Common block for Basic Package
      COMMON /BASCOM/NSTP(MXPER),PERLEN(MXPER),TSMULT(MXPER)
C  Common block for WEL Package
      COMMON /WELCOM/WELAUX(3)
      CHARACTER*16 WELAUX
C  Common block for RIV Package
      COMMON /RIVCOM/RIVAUX(3)
      CHARACTER*16 RIVAUX
C  Common block for STR Package
      COMMON /STRCOM/STRAUX(3)
      CHARACTER*16 STRAUX
C  Common block for DRN Package
      COMMON /DRNCOM/DRNAUX(3)
      CHARACTER*16 DRNAUX
C  Common block for GHB Package
      COMMON /GHBCOM/GHBAUX(3)
      CHARACTER*16 GHBAUX
C  Common block for Output Control
      COMMON /OCCOM/IBDOPT,LBHDSV,LBDDSV,
     1     IHEDFM,IDDNFM,IHEDPR,IDDNPR,IHEDSV,IDDNSV,IBUDPR,IBUDSV,
     2     IHDPR(17,MXSCRN),IDDPR(17,MXSCRN),IHDSV(17,MXSCRN),
     3     IDDSV(17,MXSCRN),IBDPR(17,MXSCRN),IBDSV(17,MXSCRN)
C  Common block for MOC
      COMMON /MOCCOM/IUMOCL,IUMOC,IUCRC,IUCOBS,NSCOL,NSROW,NSLAY,
     1     ISLAY1,ISLAY2,ISROW1,ISROW2,ISCOL1,ISCOL2,
     2     NODISP,NPTPND,ICINFL,
     3     PNEWL(51),PNEWR(51),PNEWC(51),IZONE(MXCZON),ZONCON(MXCZON),
     4     ICOB(3,MXCOB),ICOBFL(MXCOB)
      COMMON /MOCCCM/HEDMOC(2)
      CHARACTER*78 HEDMOC
C
      DATA IUMOC,IUCRC,IUCOBS,NSCOL,NSROW,NSLAY/0,0,0,0,0,0/
      DATA ICOB,ICOBFL/MXCOB*0,MXCOB*0,MXCOB*0,MXCOB*0/
      DATA IZONE,ZONCON/MXCZON*0,MXCZON*0./
      DATA PNEWL,PNEWR,PNEWC/51*0.,51*0.,51*0./
C
      DATA NSTP/MXPER*1/
      DATA PERLEN/MXPER*1./
      DATA TSMULT/MXPER*1./
C
      DATA IHDPR/IDIM*-999/
      DATA IDDPR/IDIM*-999/
      DATA IHDSV/IDIM*-999/
      DATA IDDSV/IDIM*-999/
      DATA IBDPR/IDIM*-999/
      DATA IBDSV/IDIM*-999/
      DATA IBDOPT,LBHDSV,LBDDSV,IHEDFM,IDDNFM  /1,0,0,0,0/
      DATA IHEDPR,IDDNPR,IHEDSV,IDDNSV,IBUDPR,IBUDSV /2,1,1,1,3,1/
C
      DATA WELAUX/' ',' ',' '/
      DATA RIVAUX/' ',' ',' '/
      DATA STRAUX/' ',' ',' '/
      DATA DRNAUX/' ',' ',' '/
      DATA GHBAUX/' ',' ',' '/
C
      DATA MPTYPE/'DCF','ENDPOINT','PATHLINE','TIME-SERIES','TIME',
     1            'LOCATIONS','DRAWDOWN(BINARY)','DRAWDOWN',
     2            'CONTOUR-DATA','CONTOUR-LEVEL','LIST','CBF'/
      DATA CLEGND/15*' '/
      DATA CLTITL/' '/
      DATA IGUAUN,IGUAM,GUAMIN,GUAMAX/0,1,15*0.,15*0./
C
C  IBDOPT -- tells kind of budget files
C                    = 1 old budget files
C                    = 2 compact budget files
C
C  IBUDPR,IBUDSV,IHEDPR,IDDNPR,IHEDSV,IDDNSV -- flags indicating frequency
C  of output of the indicated type (e.g. IHEDPR is printout of head):
C                   1 = none (not allowed for IBUDFL)
C                   2 = end of simulation
C                   3 = end of each stress period
C                   4 = every time step
C                   5 = A list contains the time steps and stress periods
C                       when output is desired.  For head and drawdown,
C                       layer specifications are also in the list.
C
C  IHDPR,IDDPR,IHDSV,IDDSV,IBDPR,IBDSV are lists of stress periods and time
C    steps in which the respective output is desired whenever the frequency
C    flag is 5.  There are 15 locations for layer specifications -- if layers
C    are 0, all layers are implied.
      END
